@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -21,6 +20,11 @@
 #  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
+"""
+Fabric script for Tailbone
+"""
+
+from __future__ import unicode_literals, absolute_import
 
 import shutil
 from fabric.api import task, local
@@ -31,6 +35,5 @@ def release():
     """
     Release a new version of 'Tailbone'.
     """
-
     shutil.rmtree('Tailbone.egg-info')
-    local('python setup.py sdist --formats=gztar register upload')
+    local('python setup.py sdist --formats=gztar upload')
