@@ -23,13 +23,11 @@
 ################################################################################
 
 """
-Rattail's Pyramid Framework
+Backoffice Web Application for Rattail
 """
 
 from ._version import __version__
 
-from edbob.pyramid import Session
-
 
 def includeme(config):
     config.include('tailbone.static')
