@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,15 +24,13 @@
 Application Entry Point
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 import os
-import logging
+import warnings
 
 import sqlalchemy as sa
 
-from edbob.pyramid.forms.formalchemy import TemplateEngine
-
 import rattail.db
 from rattail.config import make_config
 from rattail.exceptions import ConfigurationError
@@ -40,16 +38,14 @@ from rattail.db.util import get_engines
 from rattail.db.continuum import configure_versioning
 from rattail.db.types import GPCType
 
-import formalchemy
+import formalchemy as fa
 from pyramid.config import Configurator
 from pyramid.authentication import SessionAuthenticationPolicy
 
 import tailbone.db
 from tailbone.auth import TailboneAuthorizationPolicy
 from tailbone.forms import renderers
-
-
-log = logging.getLogger(__name__)
+from tailbone.forms.alchemy import TemplateEngine
 
 
 def make_rattail_config(settings):
@@ -59,12 +55,17 @@ def make_rattail_config(settings):
     rattail_config = settings.get('rattail_config')
     if not rattail_config:
 
-        # Initialize rattail config and embed it in the settings dict, to make it
-        # available to web requests later.
-        path = settings.get('edbob.config')
+        # initialize rattail config and embed in settings dict, to make
+        # available for web requests later
+        path = settings.get('rattail.config')
         if not path or not os.path.exists(path):
-            raise ConfigurationError("Please set 'edbob.config' in [app:main] section of config "
-                                     "to the path of your config file.  Lame, but necessary.")
+            path = settings.get('edbob.config')
+            if not path or not os.path.exists(path):
+                raise ConfigurationError("Please set 'rattail.config' in [app:main] section of config "
+                                         "to the path of your config file.  Lame, but necessary.")
+            warnings.warn("[app:main] setting 'edbob.config' is deprecated; "
+                          "please use 'rattail.config' setting instead",
+                          DeprecationWarning)
         rattail_config = make_config(path)
         settings['rattail_config'] = rattail_config
     rattail_config.configure_logging()
@@ -87,6 +88,10 @@ def make_rattail_config(settings):
     rattail.db.Session.configure(bind=rattail_engines['default'])
     tailbone.db.Session.configure(bind=rattail_engines['default'])
 
+    # Make sure rattail config object uses our scoped session, to avoid
+    # unnecessary connections (and pooling limits).
+    rattail_config._session_factory = lambda: (tailbone.db.Session(), False)
+
     # Configure (or not) Continuum versioning.
     configure_versioning(rattail_config)
     return rattail_config
@@ -101,11 +106,22 @@ def provide_postgresql_settings(settings):
     settings.setdefault('tm.attempts', 2)
 
 
+class Root(dict):
+    """
+    Root factory for Pyramid.  This is necessary to make the current request
+    available to the authorization policy object, which needs it to check if
+    the current request "is root".
+    """
+
+    def __init__(self, request):
+        self.request = request
+
+
 def make_pyramid_config(settings):
     """
     Make a Pyramid config object from the given settings.
     """
-    config = Configurator(settings=settings)
+    config = Configurator(settings=settings, root_factory=Root)
 
     # Configure user authentication / authorization.
     config.set_authentication_policy(SessionAuthenticationPolicy())
@@ -129,13 +145,12 @@ def make_pyramid_config(settings):
             config.add_tailbone_permission(groupkey, key, label)
 
     # Configure FormAlchemy.
-    formalchemy.config.engine = TemplateEngine()
-    formalchemy.FieldSet.default_renderers[sa.Boolean] = renderers.YesNoFieldRenderer
-    formalchemy.FieldSet.default_renderers[sa.Date] = renderers.DateFieldRenderer
-    # TODO: Maybe implement our own some day, but for now we must include this
-    # DateTime fix to work around a bug in edbob code.
-    formalchemy.FieldSet.default_renderers[sa.DateTime] = formalchemy.DateTimeFieldRenderer
-    formalchemy.FieldSet.default_renderers[GPCType] = renderers.GPCFieldRenderer
+    fa.config.engine = TemplateEngine()
+    fa.FieldSet.default_renderers[sa.Boolean] = renderers.YesNoFieldRenderer
+    fa.FieldSet.default_renderers[sa.Date] = renderers.DateFieldRenderer
+    fa.FieldSet.default_renderers[sa.DateTime] = renderers.DateTimeFieldRenderer
+    fa.FieldSet.default_renderers[sa.Time] = renderers.TimeFieldRenderer
+    fa.FieldSet.default_renderers[GPCType] = renderers.GPCFieldRenderer
 
     return config
 
@@ -145,7 +160,7 @@ def configure_postgresql(pyramid_config):
     Add some PostgreSQL-specific tweaks to the final app config.  Specifically,
     adds the tween necessary for graceful handling of database restarts.
     """
-    pyramid_config.add_tween('edbob.pyramid.tweens.sqlerror_tween_factory',
+    pyramid_config.add_tween('tailbone.tweens.sqlerror_tween_factory',
                              under='pyramid_tm.tm_tween_factory')
 
 
