@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,12 +24,11 @@
 Authentication & Authorization
 """
 
-from __future__ import unicode_literals
-
-from edbob.util import prettify
+from __future__ import unicode_literals, absolute_import
 
 from rattail.db import model
 from rattail.db.auth import has_permission
+from rattail.util import prettify
 
 from zope.interface import implementer
 from pyramid.interfaces import IAuthorizationPolicy
@@ -44,9 +43,14 @@ class TailboneAuthorizationPolicy(object):
     def permits(self, context, principals, permission):
         for userid in principals:
             if userid not in (Everyone, Authenticated):
-                user = Session.query(model.User).get(userid)
-                if user:
-                    return has_permission(Session(), user, permission)
+                if context.request.user and context.request.user.uuid == userid:
+                    return context.request.has_perm(permission)
+                else:
+                    assert False # should no longer happen..right?
+                    user = Session.query(model.User).get(userid)
+                    if user:
+                        if has_permission(Session(), user, permission):
+                            return True
         if Everyone in principals:
             return has_permission(Session(), None, permission)
         return False
@@ -55,14 +59,15 @@ class TailboneAuthorizationPolicy(object):
         raise NotImplementedError
 
 
-def add_permission_group(config, key, label=None):
+def add_permission_group(config, key, label=None, overwrite=True):
     """
     Add a permission group to the app configuration.
     """
     def action():
         perms = config.get_settings().get('tailbone_permissions', {})
-        group = perms.setdefault(key, {'key': key})
-        group['label'] = label or prettify(key)
+        if key not in perms or overwrite:
+            group = perms.setdefault(key, {'key': key})
+            group['label'] = label or prettify(key)
         config.add_settings({'tailbone_permissions': perms})
     config.action(None, action)
 
