@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -36,10 +36,14 @@ class ConfigExtension(BaseExtension):
     """
     Rattail config extension for Tailbone.  Does the following:
 
+     * Adds the rattail config object to the constructor kwargs for the
+       underlying Session factory.
+
      * Configures the main Tailbone database session so that it records
        changes, if the config file so dictates.
     """
     key = 'tailbone'
 
     def configure(self, config):
+        Session.configure(rattail_config=config)
         configure_session(config, Session)
