@@ -26,10 +26,11 @@ Forms
 
 from formencode import Schema
 
-from .core import Form, Field, FieldSet
+from .core import Form, Field, FieldSet, GenericFieldSet
 from .simpleform import SimpleForm, FormRenderer
 from .alchemy import AlchemyForm
 from .fields import AssociationProxyField
 from .renderers import *
 
-from tailbone.forms import renderers
+from . import renderers
+from . import validators
