@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2014 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,18 +24,31 @@
 FormAlchemy Forms
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 from rattail.core import Object
+
+import formalchemy as fa
 from pyramid.renderers import render
-from ..db import Session
+
+from tailbone.db import Session
+
+
+class TemplateEngine(fa.templates.TemplateEngine):
+    """
+    Mako template engine for FormAlchemy.
+    """
+
+    def render(self, template, prefix='/forms/', suffix='.mako', **kwargs):
+        template = ''.join((prefix, template, suffix))
+        return render(template, kwargs)
 
 
 class AlchemyForm(Object):
     """
     Form to contain a :class:`formalchemy.FieldSet` instance.
     """
-
+    id = None
     create_label = "Create"
     update_label = "Save"
 
