@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -26,14 +26,13 @@ Simple Forms
 
 from __future__ import unicode_literals, absolute_import
 
+from rattail.util import prettify
+
 import pyramid_simpleform
 from pyramid_simpleform import renderers
-
 from webhelpers.html import tags
 from webhelpers.html import HTML
 
-from edbob.util import prettify
-
 from tailbone.forms import Form
 
 
