@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2014 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,7 +24,7 @@
 FormAlchemy Grid Classes
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 from sqlalchemy.orm import object_session
 
@@ -34,17 +34,14 @@ except ImportError:
     inspect = None
     from sqlalchemy.orm import class_mapper
 
+from rattail.util import prettify
+
+import formalchemy as fa
 from webhelpers.html import tags
 from webhelpers.html import HTML
 
-import formalchemy
-
-from edbob.util import prettify
-
-from .core import Grid
-from ..db import Session
-
-__all__ = ['AlchemyGrid']
+from tailbone.db import Session
+from tailbone.grids.core import Grid
 
 
 class AlchemyGrid(Grid):
@@ -56,8 +53,8 @@ class AlchemyGrid(Grid):
 
     def __init__(self, request, cls, instances, **kwargs):
         super(AlchemyGrid, self).__init__(request, **kwargs)
-        self._formalchemy_grid = formalchemy.Grid(
-            cls, instances, session=Session(), request=request)
+        self._formalchemy_grid = fa.Grid(cls, instances, session=Session(),
+                                         request=request)
         self._formalchemy_grid.prettify = prettify
 
     def __delattr__(self, attr):
