@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,7 +24,7 @@
 Grid Search Filters
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 import re
 
@@ -37,10 +37,9 @@ from pyramid.renderers import render
 from pyramid_simpleform import Form
 from pyramid_simpleform.renderers import FormRenderer
 
-from edbob.util import prettify
-
 from rattail.core import Object
 from rattail.gpc import GPC
+from rattail.util import prettify
 
 
 class SearchFilter(Object):
