@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,11 +24,10 @@
 Core Grid Classes
 """
 
-from __future__ import unicode_literals
-
-from edbob.util import prettify
+from __future__ import unicode_literals, absolute_import
 
 from rattail.db.api import get_setting, save_setting
+from rattail.util import prettify
 
 from pyramid.renderers import render
 from webhelpers.html import HTML, tags
@@ -55,7 +54,7 @@ class Grid(object):
         self.data = data
         self.main_actions = main_actions
         self.more_actions = more_actions
-        self.joiners = joiners
+        self.joiners = joiners or {} # use new/different empty dict for each instance
 
         # Set extra attributes first, in case other init logic depends on any
         # of them (i.e. in subclasses).
@@ -79,7 +78,7 @@ class Grid(object):
 
         self.width = width
         self.checkboxes = checkboxes
-        self.row_attrs = row_attrs
+        self.row_attrs = row_attrs or {}
         self.cell_attrs = cell_attrs
 
     def get_default_filters(self):
@@ -160,10 +159,10 @@ class Grid(object):
         instance attributes.
         """
         # Initial settings come from class defaults.
-        settings = {
-            'sortkey':  self.default_sortkey,
-            'sortdir':  self.default_sortdir,
-        }
+        settings = {}
+        if self.sortable:
+            settings['sortkey'] = self.default_sortkey
+            settings['sortdir'] = self.default_sortdir
         if self.pageable:
             settings['pagesize'] = self.default_pagesize
             settings['page'] = self.default_page
@@ -246,11 +245,21 @@ class Grid(object):
         """
         Check to see if the current user has default settings on file for this grid.
         """
-        if not self.request.user:
+        user = self.request.user
+        if not user:
             return False
+
+        # NOTE: we used to leverage `self.session` here, but sometimes we might
+        # be showing a grid of data from another system...so always use
+        # Tailbone Session now, for the settings.  hopefully that didn't break
+        # anything...
+        session = Session()
+        if user not in session:
+            user = session.merge(user)
+
         # User defaults should have all or nothing, so just check one key.
-        key = 'tailbone.{0}.grid.{1}.sortkey'.format(self.request.user.uuid, self.key)
-        return get_setting(Session(), key) is not None
+        key = 'tailbone.{}.grid.{}.sortkey'.format(user.uuid, self.key)
+        return get_setting(session, key) is not None
 
     def apply_user_defaults(self, settings):
         """
@@ -508,6 +517,7 @@ class Grid(object):
         Render the complete grid, including filters.
         """
         kwargs['grid'] = self
+        kwargs.setdefault('allow_save_defaults', True)
         return render(template, kwargs)
 
     def render_grid(self, template='/newgrids/grid.mako', **kwargs):
@@ -571,7 +581,9 @@ class Grid(object):
             else:
                 kwargs['class_'] = 'sortable'
             kwargs['data-sortkey'] = column.key
-            kwargs['c'] = tags.link_to(column.label, '#')
+            kwargs['c'] = tags.link_to(column.label, '#', title=column.title)
+        elif column.title:
+            kwargs['c'] = HTML.tag('span', title=column.title, c=column.label)
         return HTML.tag('th', **kwargs)
 
     @property
@@ -581,29 +593,29 @@ class Grid(object):
         """
         return bool(self.main_actions or self.more_actions)
 
-    def render_actions(self, row):
+    def render_actions(self, row, i):
         """
         Returns the rendered contents of the 'actions' column for a given row.
         """
-        main_actions = filter(None, [self.render_action(a, row) for a in self.main_actions])
-        more_actions = filter(None, [self.render_action(a, row) for a in self.more_actions])
+        main_actions = filter(None, [self.render_action(a, row, i) for a in self.main_actions])
+        more_actions = filter(None, [self.render_action(a, row, i) for a in self.more_actions])
         if more_actions:
             icon = HTML.tag('span', class_='ui-icon ui-icon-carat-1-e')
             link = tags.link_to("More" + icon, '#', class_='more')
             main_actions.append(link + HTML.tag('div', class_='more', c=more_actions))
-            # main_actions.append(tags.link_to("More" + icon + HTML.literal('').join(more_actions), '#', class_='more'))
         return HTML.literal('').join(main_actions)
 
-    def render_action(self, action, row):
+    def render_action(self, action, row, i):
         """
         Renders an action menu item (link) for the given row.
         """
-        url = action.get_url(row)
+        url = action.get_url(row, i)
         if url:
+            kwargs = {'class_': action.key}
             if action.icon:
-                icon = HTML.tag('span', class_='ui-icon ui-icon-{0}'.format(action.icon))
-                return tags.link_to(icon + action.label, url)
-            return tags.link_to(action.label, url)
+                icon = HTML.tag('span', class_='ui-icon ui-icon-{}'.format(action.icon))
+                return tags.link_to(icon + action.label, url, **kwargs)
+            return tags.link_to(action.label, url, **kwargs)
 
     def iter_rows(self):
         return self.make_visible_data()
@@ -657,7 +669,7 @@ class Grid(object):
         return self.cell_attrs
 
     def render_cell(self, row, column):
-        return unicode(row[column.key])
+        return column.render(row[column.key])
 
     def get_pagesize_options(self):
         # TODO: Make configurable or something...
@@ -677,9 +689,16 @@ class GridColumn(object):
        Human-facing label for the column, i.e. displayed in the header.
     """
 
-    def __init__(self, key, label=None):
+    def __init__(self, key, label=None, title=None):
         self.key = key
         self.label = label or prettify(key)
+        self.title = title
+
+    def render(self, value):
+        """
+        Render the given value, to be displayed within a grid cell.
+        """
+        return unicode(value)
 
 
 class GridAction(object):
@@ -694,10 +713,10 @@ class GridAction(object):
         self.icon = icon
         self.url = url
 
-    def get_url(self, row):
+    def get_url(self, row, i):
         """
         Returns an action URL for the given row.
         """
         if callable(self.url):
-            return self.url(row)
+            return self.url(row, i)
         return self.url
