@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2014 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -20,12 +20,11 @@
 #  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
-
 """
 Progress Indicator
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 from beaker.session import Session
 
@@ -56,6 +55,7 @@ class SessionProgress(object):
         self.clear()
         self.session['message'] = message
         self.session['maximum'] = maximum
+        self.session['maximum_display'] = '{:,d}'.format(maximum)
         self.session['value'] = 0
         self.session.save()
         return self
