@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2014 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -21,13 +20,12 @@
 #  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
-
 """
 Static Assets
 """
 
+from __future__ import unicode_literals
+
 
 def includeme(config):
-    # TODO: Remove edbob.
-    config.include('edbob.pyramid.static')
     config.add_static_view('tailbone', 'tailbone:static')
