@@ -112,6 +112,16 @@ $(function() {
     $('input[type=submit]').button();
     $('input[type=reset]').button();
 
+    /* Also automatically disable any buttons marked for that. */
+    $('a.button[disabled=disabled]').button('option', 'disabled', true);
+
+    /*
+     * Apply timepicker behavior to text inputs which are marked for it.
+     */
+    $('input[type=text].timepicker').timepicker({
+        showPeriod: true
+    });
+
     /*
      * When filter labels are clicked, (un)check the associated checkbox.
      */
