@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -21,19 +20,22 @@
 #  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
-
 """
 Event Subscribers
 """
 
-from pyramid import threadlocal
-import rattail
-from . import helpers
+from __future__ import unicode_literals, absolute_import
 
-from pyramid.security import authenticated_userid
-from .db import Session
-from rattail.db.model import User
-from rattail.db.auth import has_permission
+import rattail
+from rattail import enum
+from rattail.db import model
+from rattail.db.auth import has_permission, administrator_role
+
+from pyramid import threadlocal
+
+import tailbone
+from tailbone import helpers
+from tailbone.db import Session
 
 
 def add_rattail_config_attribute_to_request(event):
@@ -76,6 +78,25 @@ def before_render(event):
     renderer_globals['h'] = helpers
     renderer_globals['url'] = request.route_url
     renderer_globals['rattail'] = rattail
+    renderer_globals['tailbone'] = tailbone
+
+
+def add_inbox_count(event):
+    """
+    Adds the current user's inbox message count to the global renderer context.
+
+    Note that this is not enabled by default; to turn it on you must do this:
+
+       config.add_subscriber('tailbone.subscribers.add_inbox_count', 'pyramid.events.BeforeRender')
+    """
+    request = event.get('request') or threadlocal.get_current_request()
+    if request.user:
+        renderer_globals = event
+        renderer_globals['inbox_count'] = Session.query(model.Message)\
+                                                 .outerjoin(model.MessageRecipient)\
+                                                 .filter(model.MessageRecipient.recipient == Session.merge(request.user))\
+                                                 .filter(model.MessageRecipient.status == enum.MESSAGE_STATUS_INBOX)\
+                                                 .count()
 
 
 def context_found(event):
@@ -86,6 +107,10 @@ def context_found(event):
 
     * The currently logged-in user instance (if any), as ``user``.
 
+    * ``is_admin`` flag indicating whether user has the Administrator role.
+
+    * ``is_root`` flag indicating whether user is currently elevated to root.
+
     * A shortcut method for permission checking, as ``has_perm()``.
 
     * A shortcut method for fetching the referrer, as ``get_referrer()``.
@@ -94,19 +119,24 @@ def context_found(event):
     request = event.request
 
     request.user = None
-    uuid = authenticated_userid(request)
+    uuid = request.authenticated_userid
     if uuid:
-        request.user = Session.query(User).get(uuid)
+        request.user = Session.query(model.User).get(uuid)
         if request.user:
             Session().set_continuum_user(request.user)
 
-    def has_perm(perm):
-        return has_permission(Session(), request.user, perm)
+    request.is_admin = request.user and administrator_role(Session()) in request.user.roles
+    request.is_root = request.is_admin and request.session.get('is_root', False)
+
+    def has_perm(name):
+        if has_permission(Session(), request.user, name):
+            return True
+        return request.is_root
     request.has_perm = has_perm
 
-    def has_any_perm(*perms):
-        for perm in perms:
-            if has_permission(Session(), request.user, perm):
+    def has_any_perm(*names):
+        for name in names:
+            if has_perm(name):
                 return True
         return False
     request.has_any_perm = has_any_perm
