@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2014 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,7 +24,7 @@
 Utilities
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 import datetime
 
@@ -64,3 +64,43 @@ def pretty_datetime(config, value):
     return HTML.tag('span',
                     title=value.strftime('%Y-%m-%d %H:%M:%S %Z%z'),
                     c=humanize.naturaltime(time_ago))
+
+
+def raw_datetime(config, value):
+    """
+    Formats a datetime as a "raw" human-readable string, with a tooltip
+    showing the more human-friendly "time since" equivalent.
+
+    :param config: Reference to a config object.
+
+    :param value: A ``datetime.datetime`` instance.  Note that if this instance
+       is not timezone-aware, its timezone is assumed to be UTC.
+    """
+    if not value:
+        return ''
+
+    # Make sure we're dealing with a tz-aware value.  If we're given a naive
+    # value, we assume it to be local to the UTC timezone.
+    if not value.tzinfo:
+        value = pytz.utc.localize(value)
+
+    # Calculate time diff using UTC.
+    time_ago = datetime.datetime.utcnow() - make_utc(value)
+
+    # Convert value to local timezone.
+    local = timezone(config)
+    value = local.normalize(value.astimezone(local))
+
+    kwargs = {}
+
+    # Avoid strftime error when year falls before epoch.
+    if value.year >= 1900:
+        kwargs['c'] = value.strftime('%Y-%m-%d %I:%M:%S %p')
+    else:
+        kwargs['c'] = unicode(value)
+
+    # Avoid humanize error when calculating huge time diff.
+    if abs(time_ago.days) < 100000:
+        kwargs['title'] = humanize.naturaltime(time_ago)
+
+    return HTML.tag('span', **kwargs)
