@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2014 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -20,16 +20,17 @@
 #  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
-
 """
 Pyramid Views
 """
 
+from __future__ import unicode_literals, absolute_import
+
 from .core import View
 from tailbone.views.grids import (
     GridView, AlchemyGridView, SortableAlchemyGridView,
     PagedAlchemyGridView, SearchableAlchemyGridView)
-from .crud import *
+from .crud import CrudView
 from .master import MasterView
 from tailbone.views.autocomplete import AutocompleteView
 
@@ -53,6 +54,7 @@ def includeme(config):
                     renderer='/home.mako')
 
     config.include('tailbone.views.core')
+    config.include('tailbone.views.common')
 
     config.include('tailbone.views.auth')
     config.include('tailbone.views.batches')
@@ -64,14 +66,22 @@ def includeme(config):
     config.include('tailbone.views.datasync')
     config.include('tailbone.views.departments')
     config.include('tailbone.views.depositlinks')
+    config.include('tailbone.views.email')
     config.include('tailbone.views.employees')
     config.include('tailbone.views.families')
+    config.include('tailbone.views.handheld')
+    config.include('tailbone.views.inventory')
     config.include('tailbone.views.labels')
+    config.include('tailbone.views.messages')
     config.include('tailbone.views.people')
     config.include('tailbone.views.products')
     config.include('tailbone.views.progress')
-    config.include(u'tailbone.views.reportcodes')
+    config.include('tailbone.views.purchases')
+    config.include('tailbone.views.reportcodes')
+    config.include('tailbone.views.reports')
     config.include('tailbone.views.roles')
+    config.include('tailbone.views.settings')
+    config.include('tailbone.views.shifts')
     config.include('tailbone.views.stores')
     config.include('tailbone.views.subdepartments')
     config.include('tailbone.views.taxes')
