@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,20 +24,19 @@
 Auth Views
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
-from pyramid.httpexceptions import HTTPFound
-from pyramid.security import remember, forget, authenticated_userid
+from rattail.db.auth import authenticate_user, set_user_password
 
+import formencode
+from pyramid.httpexceptions import HTTPFound, HTTPForbidden
+from pyramid.security import remember, forget
+from pyramid_simpleform import Form
 from webhelpers.html import literal
 from webhelpers.html import tags
 
-import formencode
-from pyramid_simpleform import Form
-from ..forms.simpleform import FormRenderer
-
-from ..db import Session
-from rattail.db.auth import authenticate_user, set_user_password
+from tailbone.db import Session
+from tailbone.forms.simpleform import FormRenderer
 
 
 def forbidden(request):
@@ -48,7 +47,7 @@ def forbidden(request):
     appropriate view.
     """
     msg = literal("You do not have permission to do that.")
-    if not authenticated_userid(request):
+    if not request.authenticated_userid:
         msg += literal("&nbsp; (Perhaps you should %s?)" %
                        tags.link_to("log in", request.route_url('login')))
         # Store current URL in session, for smarter redirect after login.
@@ -104,6 +103,28 @@ def logout(request):
     return HTTPFound(location=referrer, headers=headers)
 
 
+def become_root(request):
+    """
+    Elevate the current request to 'root' for full system access.
+    """
+    if not request.is_admin:
+        raise HTTPForbidden()
+    request.session['is_root'] = True
+    request.session.flash("You have been elevated to 'root' and now have full system access")
+    return HTTPFound(location=request.get_referrer())
+
+
+def stop_root(request):
+    """
+    Lower the current request from 'root' back to normal access.
+    """
+    if not request.is_admin:
+        raise HTTPForbidden()
+    request.session['is_root'] = False
+    request.session.flash("Your normal system access has been restored")
+    return HTTPFound(location=request.get_referrer())
+
+
 class CurrentPasswordCorrect(formencode.validators.FancyValidator):
 
     def _to_python(self, value, state):
@@ -148,6 +169,8 @@ def change_password(request):
 def add_routes(config):
     config.add_route('login',           '/login')
     config.add_route('logout',          '/logout')
+    config.add_route('become_root',     '/root/yes')
+    config.add_route('stop_root',       '/root/no')
     config.add_route('change_password', '/change-password')
     
 
@@ -161,5 +184,8 @@ def includeme(config):
 
     config.add_view(logout, route_name='logout')
 
+    config.add_view(become_root, route_name='become_root')
+    config.add_view(stop_root, route_name='stop_root')
+
     config.add_view(change_password, route_name='change_password',
                     renderer='/change_password.mako')
