@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -43,9 +43,10 @@ class CategoriesView(MasterView):
     def configure_grid(self, g):
         g.filters['name'].default_active = True
         g.filters['name'].default_verb = 'contains'
-        g.default_sortkey = 'number'
+        g.default_sortkey = 'code'
         g.configure(
             include=[
+                g.code,
                 g.number,
                 g.name,
                 g.department,
@@ -55,6 +56,7 @@ class CategoriesView(MasterView):
     def configure_fieldset(self, fs):
         fs.configure(
             include=[
+                fs.code,
                 fs.number,
                 fs.name,
                 fs.department,
