@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,10 +24,13 @@
 Base View Class
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 from rattail.db import model
 
+from pyramid import httpexceptions
+from pyramid.renderers import render_to_response
+
 from tailbone.db import Session
 
 
@@ -38,13 +41,16 @@ class View(object):
 
     def __init__(self, request):
         self.request = request
+        config = self.rattail_config
+        if config:
+            self.enum = config.get_enum()
 
     @property
     def rattail_config(self):
         """
         Reference to the effective Rattail config object.
         """
-        return self.request.rattail_config
+        return getattr(self.request, 'rattail_config', None)
 
     def late_login_user(self):
         """
@@ -56,6 +62,18 @@ class View(object):
             if uuid:
                 return Session.query(model.User).get(uuid)
 
+    def redirect(self, url, **kwargs):
+        """
+        Convenience method to return a HTTP 302 response.
+        """
+        return httpexceptions.HTTPFound(location=url, **kwargs)
+
+    def render_progress(self, kwargs):
+        """
+        Render the progress page, with given kwargs as context.
+        """
+        return render_to_response('/progress.mako', kwargs, request=self.request)
+
 
 def fake_error(request):
     """
