@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,7 +24,7 @@
 CRUD View
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 try:
     from sqlalchemy.inspection import inspect
@@ -38,20 +38,14 @@ from sqlalchemy_continuum.utils import is_versioned
 
 from rattail.db import model
 from rattail.db.continuum import count_versions, model_transaction_query
+from rattail.util import prettify
 
+from formalchemy import FieldSet
 from pyramid.httpexceptions import HTTPFound, HTTPNotFound
 
-from .core import View
-
-from ..forms import AlchemyForm
-from formalchemy import FieldSet
-
-from edbob.util import prettify
-
 from tailbone.db import Session
-
-
-__all__ = ['CrudView']
+from tailbone.views.core import View
+from tailbone.forms import AlchemyForm
 
 
 class CrudView(View):
