@@ -64,6 +64,14 @@ class CustomerGroupsView(MasterView):
         for assignment in q:
             Session.delete(assignment)
 
+    @classmethod
+    def defaults(cls, config):
+
+        # fix permission group title
+        config.add_tailbone_permission_group('customergroups', "Customer Groups")
+
+        cls._defaults(config)
+
 
 def includeme(config):
     CustomerGroupsView.defaults(config)
