@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,12 +24,13 @@
 Department Views
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 from rattail.db import model
 
 from tailbone.views import MasterView, AutocompleteView, AlchemyGridView
 from tailbone.views.continuum import VersionView, version_defaults
+from tailbone.newgrids import AlchemyGrid, GridAction
 
 
 class DepartmentsView(MasterView):
@@ -57,6 +58,28 @@ class DepartmentsView(MasterView):
             ])
         return fs
 
+    def template_kwargs_view(self, **kwargs):
+        department = kwargs['instance']
+        if department.employees:
+
+            # TODO: This is the second attempt (after role.users) at using a
+            # new grid outside of the context of a primary master grid.  The
+            # API here is really much hairier than I'd like...  Looks like we
+            # shouldn't need a key for this one, for instance (no settings
+            # required), but there is plenty of room for improvement here.
+            employees = sorted(department.employees, key=unicode)
+            employees = AlchemyGrid('departments.employees', self.request, data=employees, model_class=model.Employee,
+                                      main_actions=[
+                                          GridAction('view', icon='zoomin',
+                                                     url=lambda r, i: self.request.route_url('employees.view', uuid=r.uuid)),
+                                      ])
+            employees.configure(include=[employees.display_name], readonly=True)
+            kwargs['employees'] = employees
+
+        else:
+            kwargs['employees'] = None
+        return kwargs
+
 
 class DepartmentVersionView(VersionView):
     """
