@@ -26,15 +26,40 @@ Email Views
 
 from __future__ import unicode_literals, absolute_import
 
+import formalchemy
+from formalchemy.helpers import text_area
 from pyramid.httpexceptions import HTTPFound
 
 from rattail import mail
+from rattail.db import api
+from rattail.config import parse_list
 
 from tailbone import forms
+from tailbone.db import Session
 from tailbone.views import MasterView, View
 from tailbone.newgrids import Grid, GridColumn
 
 
+class EmailListGridColumn(GridColumn):
+
+    def render(self, value):
+        if not value:
+            return ''
+        recips = parse_list(value)
+        if len(recips) < 3:
+            return value
+        return "{}, ...".format(', '.join(recips[:2]))
+
+
+class EmailListFieldRenderer(formalchemy.TextAreaFieldRenderer):
+
+    def render(self, **kwargs):
+        if isinstance(kwargs.get('size'), tuple):
+            kwargs['size'] = 'x'.join([str(i) for i in kwargs['size']])
+        value = '\n'.join(parse_list(self.value))
+        return text_area(self.name, content=value, **kwargs)
+
+
 class ProfilesView(MasterView):
     """
     Master view for email admin (settings/preview).
@@ -49,7 +74,6 @@ class ProfilesView(MasterView):
     pageable = False
 
     creatable = False
-    editable = False
     deletable = False
 
     def get_data(self, session=None):
@@ -67,6 +91,7 @@ class ProfilesView(MasterView):
                 return ', '.join(recips)
         data = email.sample_data(self.request)
         return {
+            '_email': email,
             'key': email.key,
             'fallback_key': email.fallback_key,
             'description': email.__doc__,
@@ -77,6 +102,7 @@ class ProfilesView(MasterView):
             'to': get_recips('to'),
             'cc': get_recips('cc'),
             'bcc': get_recips('bcc'),
+            'enabled': email.get_enabled(),
         }
 
     def configure_grid(self, g):
@@ -84,7 +110,7 @@ class ProfilesView(MasterView):
             GridColumn('key'),
             GridColumn('prefix'),
             GridColumn('subject'),
-            GridColumn('to'),
+            EmailListGridColumn('to'),
         ]
 
         g.sorters['key'] = g.make_sorter('key', foldcase=True)
@@ -93,49 +119,56 @@ class ProfilesView(MasterView):
         g.sorters['to'] = g.make_sorter('to', foldcase=True)
         g.default_sortkey = 'key'
 
-        # g.main_actions = []
-        g.more_actions = []
+        # Make edit link visible by default, no "More" actions.
+        g.main_actions.append(g.more_actions.pop())
 
     def get_instance(self):
         key = self.request.matchdict['key']
         return self.normalize(mail.get_email(self.rattail_config, key))
 
     def get_instance_title(self, email):
-        return email['key']
+        return email['_email'].get_complete_subject()
 
     def make_form(self, email, **kwargs):
         """
         Make a simple form for use with CRUD views.
         """
-        # TODO: This needs all kinds of help still...
+        fs = forms.GenericFieldSet(email)
+        fs.append(formalchemy.Field('key', value=email['key'], readonly=True))
+        fs.append(formalchemy.Field('fallback_key', value=email['fallback_key'], readonly=True))
+        fs.append(formalchemy.Field('description', value=email['description'], readonly=True))
+        fs.append(formalchemy.Field('prefix', value=email['prefix'], label="Subject Prefix"))
+        fs.append(formalchemy.Field('subject', value=email['subject'], label="Subject Text"))
+        fs.append(formalchemy.Field('sender', value=email['sender'], label="From"))
+        fs.append(formalchemy.Field('replyto', value=email['replyto'], label="Reply-To"))
+        fs.append(formalchemy.Field('to', value=email['to'], renderer=EmailListFieldRenderer, size='60x6'))
+        fs.append(formalchemy.Field('cc', value=email['cc'], renderer=EmailListFieldRenderer, size='60x2'))
+        fs.append(formalchemy.Field('bcc', value=email['bcc'], renderer=EmailListFieldRenderer, size='60x2'))
+        fs.append(formalchemy.Field('enabled', type=formalchemy.types.Boolean, value=email['enabled']))
 
-        class EmailSchema(forms.Schema):
-            pass
-
-        form = forms.SimpleForm(self.request, schema=EmailSchema(), obj=email)
-        form.creating = self.creating
-        form.editing = self.editing
+        form = forms.AlchemyForm(self.request, fs,
+                                 creating=self.creating,
+                                 editing=self.editing,
+                                 action_url=self.request.current_route_url(_query=None),
+                                 cancel_url=self.get_action_url('view', email))
         form.readonly = self.viewing
-
-        if self.creating:
-            form.cancel_url = self.get_index_url()
-        else:
-            form.cancel_url = self.get_action_url('view', email)
-
-        form.fieldset = forms.FieldSet()
-        form.fieldset.fields['key'] = forms.Field('key', value=email['key'])
-        form.fieldset.fields['fallback_key'] = forms.Field('fallback_key', value=email['fallback_key'])
-        form.fieldset.fields['prefix'] = forms.Field('prefix', value=email['prefix'], label="Subject Prefix")
-        form.fieldset.fields['subject'] = forms.Field('subject', value=email['subject'], label="Subject Text")
-        form.fieldset.fields['description'] = forms.Field('description', value=email['description'])
-        form.fieldset.fields['sender'] = forms.Field('sender', value=email['sender'], label="From")
-        form.fieldset.fields['replyto'] = forms.Field('replyto', value=email['replyto'], label="Reply-To")
-        form.fieldset.fields['to'] = forms.Field('to', value=email['to'])
-        form.fieldset.fields['cc'] = forms.Field('cc', value=email['cc'])
-        form.fieldset.fields['bcc'] = forms.Field('bcc', value=email['bcc'])
-
         return form
 
+    def save_form(self, form):
+        fs = form.fieldset
+        fs.sync()
+        key = fs.key._value
+
+        session = Session()
+        api.save_setting(session, 'rattail.mail.{}.prefix'.format(key), fs.prefix._value)
+        api.save_setting(session, 'rattail.mail.{}.subject'.format(key), fs.subject._value)
+        api.save_setting(session, 'rattail.mail.{}.from'.format(key), fs.sender._value)
+        api.save_setting(session, 'rattail.mail.{}.replyto'.format(key), fs.replyto._value)
+        api.save_setting(session, 'rattail.mail.{}.to'.format(key), (fs.to._value or '').replace('\n', ', '))
+        api.save_setting(session, 'rattail.mail.{}.cc'.format(key), (fs.cc._value or '').replace('\n', ', '))
+        api.save_setting(session, 'rattail.mail.{}.bcc'.format(key), (fs.bcc._value or '').replace('\n', ', '))
+        api.save_setting(session, 'rattail.mail.{}.enabled'.format(key), unicode(fs.enabled._value).lower())
+
     def template_kwargs_view(self, **kwargs):
         key = self.request.matchdict['key']
         kwargs['email'] = mail.get_email(self.rattail_config, key)
