@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -31,8 +31,12 @@ import sqlalchemy as sa
 from rattail import enum
 from rattail.db import model
 
+import formalchemy
+
 from tailbone import forms
+from tailbone.db import Session
 from tailbone.views import MasterView, AutocompleteView
+from tailbone.newgrids import AlchemyGrid, GridAction
 from tailbone.newgrids.filters import EnumValueRenderer
 
 
@@ -111,6 +115,8 @@ class EmployeesView(MasterView):
         fs.append(forms.AssociationProxyField('first_name'))
         fs.append(forms.AssociationProxyField('last_name'))
         fs.append(forms.AssociationProxyField('display_name'))
+        fs.append(StoresField('stores'))
+        fs.append(DepartmentsField('departments'))
         fs.configure(
             include=[
                 fs.id.label("ID"),
@@ -120,9 +126,67 @@ class EmployeesView(MasterView):
                 fs.phone.label("Phone Number").readonly(),
                 fs.email.label("Email Address").readonly(),
                 fs.status.with_renderer(forms.EnumFieldRenderer(enum.EMPLOYEE_STATUS)),
+                fs.stores,
+                fs.departments,
             ])
 
 
+class StoresField(formalchemy.Field):
+
+    def __init__(self, name, **kwargs):
+        kwargs.setdefault('type', formalchemy.types.Set)
+        kwargs.setdefault('options', Session.query(model.Store).order_by(model.Store.name))
+        kwargs.setdefault('value', self.get_value)
+        kwargs.setdefault('multiple', True)
+        kwargs.setdefault('size', 3)
+        formalchemy.Field.__init__(self, name=name, **kwargs)
+
+    def get_value(self, employee):
+        return [s.uuid for s in employee.stores]
+
+    def sync(self):
+        if not self.is_readonly():
+            employee = self.parent.model
+            old_stores = set([s.uuid for s in employee.stores])
+            new_stores = set(self._deserialize())
+            for uuid in new_stores:
+                if uuid not in old_stores:
+                    employee._stores.append(model.EmployeeStore(store_uuid=uuid))
+            for uuid in old_stores:
+                if uuid not in new_stores:
+                    store = Session.query(model.Store).get(uuid)
+                    assert store
+                    employee.stores.remove(store)
+
+
+class DepartmentsField(formalchemy.Field):
+
+    def __init__(self, name, **kwargs):
+        kwargs.setdefault('type', formalchemy.types.Set)
+        kwargs.setdefault('options', Session.query(model.Department).order_by(model.Department.name))
+        kwargs.setdefault('value', self.get_value)
+        kwargs.setdefault('multiple', True)
+        kwargs.setdefault('size', 10)
+        formalchemy.Field.__init__(self, name=name, **kwargs)
+
+    def get_value(self, employee):
+        return [d.uuid for d in employee.departments]
+
+    def sync(self):
+        if not self.is_readonly():
+            employee = self.parent.model
+            old_depts = set([d.uuid for d in employee.departments])
+            new_depts = set(self._deserialize())
+            for uuid in new_depts:
+                if uuid not in old_depts:
+                    employee._departments.append(model.EmployeeDepartment(department_uuid=uuid))
+            for uuid in old_depts:
+                if uuid not in new_depts:
+                    dept = Session.query(model.Department).get(uuid)
+                    assert dept
+                    employee.departments.remove(dept)
+
+
 class EmployeesAutocomplete(AutocompleteView):
     """
     Autocomplete view for the Employee model, but restricted to return only
