@@ -26,5 +26,7 @@
 Grid Views
 """
 
-from .core import *
-from .alchemy import *
+from tailbone.views.grids.core import GridView
+from tailbone.views.grids.alchemy import (
+    AlchemyGridView, SortableAlchemyGridView,
+    PagedAlchemyGridView, SearchableAlchemyGridView)
