@@ -69,9 +69,9 @@ class PeopleView(MasterView):
 
         g.configure(
             include=[
+                g.display_name.label("Full Name"),
                 g.first_name,
                 g.last_name,
-                g.display_name,
                 g.phone.label("Phone Number"),
                 g.email.label("Email Address"),
             ],
@@ -92,10 +92,10 @@ class PeopleView(MasterView):
     def configure_fieldset(self, fs):
         fs.configure(
             include=[
+                fs.display_name.label("Full Name"),
                 fs.first_name,
                 fs.middle_name,
                 fs.last_name,
-                fs.display_name,
                 fs.phone.label("Phone Number").readonly(),
                 fs.email.label("Email Address").readonly(),
                 fs.address.label("Mailing Address").readonly(),
