@@ -33,7 +33,9 @@ def progress(request):
     key = request.matchdict['key']
     session = get_progress_session(request, key)
     if session.get('complete'):
-        request.session.flash(session.get('success_msg', "The process has completed successfully."))
+        msg = session.get('success_msg')
+        if msg:
+            request.session.flash(msg)
     elif session.get('error'):
         request.session.flash(session.get('error_msg', "An unspecified error occurred."), 'error')
     return session
