@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2014 Lance Edgar
+#  Copyright © 2010-2015 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -20,7 +20,6 @@
 #  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
-
 """
 Report Views
 """
@@ -46,14 +45,18 @@ plu_upc_pattern = re.compile(r'^000000000(\d{5})$')
 weighted_upc_pattern = re.compile(r'^002(\d{5})00000\d$')
 
 def get_upc(product):
-    upc = '%014u' % product.upc
+    """
+    UPC formatter.  Strips PLUs to bare number, and adds "minus check digit"
+    for non-PLU UPCs.
+    """
+    upc = unicode(product.upc)
     m = plu_upc_pattern.match(upc)
     if m:
-        return str(int(m.group(1)))
+        return unicode(int(m.group(1)))
     m = weighted_upc_pattern.match(upc)
     if m:
-        return str(int(m.group(1)))
-    return upc
+        return unicode(int(m.group(1)))
+    return '{0}-{1}'.format(upc[:-1], upc[-1])
 
 
 class OrderingWorksheet(View):
@@ -92,6 +95,7 @@ class OrderingWorksheet(View):
 
         q = Session.query(model.ProductCost)
         q = q.join(model.Product)
+        q = q.filter(model.Product.deleted == False)
         q = q.filter(model.ProductCost.vendor == vendor)
         q = q.filter(model.Product.department_uuid.in_([x.uuid for x in departments]))
         if preferred_only:
@@ -165,9 +169,10 @@ class InventoryWorksheet(View):
         def get_products(subdepartment):
             q = Session.query(model.Product)
             q = q.outerjoin(model.Brand)
+            q = q.filter(model.Product.deleted == False)
             q = q.filter(model.Product.subdepartment == subdepartment)
             if self.request.params.get('weighted-only'):
-                q = q.filter(model.Product.unit_of_measure == enum.UNIT_OF_MEASURE_POUND)
+                q = q.filter(model.Product.weighed == True)
             if self.request.params.get('exclude-not-for-sale'):
                 q = q.filter(model.Product.not_for_sale == False)
             q = q.order_by(model.Brand.name, model.Product.description)
