@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,14 +24,15 @@
 Role Views
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 from rattail.db import model
-from rattail.db.auth import has_permission, administrator_role, guest_role
+from rattail.db.auth import has_permission, administrator_role, guest_role, authenticated_role
 
 import formalchemy
 from webhelpers.html import HTML, tags
 
+from tailbone import forms
 from tailbone.db import Session
 from tailbone.views import MasterView
 from tailbone.views.continuum import VersionView, version_defaults
@@ -49,52 +50,6 @@ class PermissionsField(formalchemy.Field):
             role.permissions = self.renderer.deserialize()
 
 
-def PermissionsFieldRenderer(permissions, *args, **kwargs):
-
-    class PermissionsFieldRenderer(formalchemy.FieldRenderer):
-
-        def deserialize(self):
-            perms = []
-            i = len(self.name) + 1
-            for key in self.params:
-                if key.startswith(self.name):
-                    perms.append(key[i:])
-            return perms
-
-        def _render(self, readonly=False, **kwargs):
-            role = self.field.model
-            admin = administrator_role(Session())
-            if role is admin:
-                html = HTML.tag('p', c="This is the administrative role; "
-                                "it has full access to the entire system.")
-                if not readonly:
-                    html += tags.hidden(self.name, value='') # ugly hack..or good idea?
-            else:
-                html = ''
-                for groupkey in sorted(permissions, key=lambda k: permissions[k]['label']):
-                    inner = HTML.tag('p', c=permissions[groupkey]['label'])
-                    perms = permissions[groupkey]['perms']
-                    for key in sorted(perms, key=lambda p: perms[p]['label']):
-                        checked = has_permission(Session(), role, key, include_guest=False)
-                        label = perms[key]['label']
-                        if readonly:
-                            span = HTML.tag('span', c="[X]" if checked else "[ ]")
-                            inner += HTML.tag('p', class_='perm', c=span + ' ' + label)
-                        else:
-                            inner += tags.checkbox(self.name + '-' + key,
-                                                   checked=checked, label=label)
-                    html += HTML.tag('div', class_='group', c=inner)
-            return html
-
-        def render(self, **kwargs):
-            return self._render(**kwargs)
-
-        def render_readonly(self, **kwargs):
-            return self._render(readonly=True, **kwargs)
-
-    return PermissionsFieldRenderer
-
-
 class RolesView(MasterView):
     """
     Master view for the Role model.
@@ -114,7 +69,7 @@ class RolesView(MasterView):
     def configure_fieldset(self, fs):
         fs.append(PermissionsField('permissions'))
         permissions = self.request.registry.settings.get('tailbone_permissions', {})
-        fs.permissions.set(renderer=PermissionsFieldRenderer(permissions))
+        fs.permissions.set(renderer=forms.renderers.PermissionsFieldRenderer(permissions))
         fs.configure(
             include=[
                 fs.name,
@@ -134,7 +89,7 @@ class RolesView(MasterView):
             users = AlchemyGrid('roles.users', self.request, data=users, model_class=model.User,
                                 main_actions=[
                                     GridAction('view', icon='zoomin',
-                                               url=lambda u: self.request.route_url('users.view', uuid=u.uuid)),
+                                               url=lambda r, i: self.request.route_url('users.view', uuid=r.uuid)),
                                 ])
             users.configure(include=[users.username], readonly=True)
             kwargs['users'] = users
@@ -142,14 +97,16 @@ class RolesView(MasterView):
         else:
             kwargs['users'] = None
         kwargs['guest_role'] = guest_role(Session())
+        kwargs['authenticated_role'] = authenticated_role(Session())
         return kwargs
 
     def before_delete(self, role):
         admin = administrator_role(Session())
         guest = guest_role(Session())
-        if role in (admin, guest):
-            self.request.session.flash("You may not delete the {0} role.".format(role.name), 'error')
-            return self.redirect(self.request.get_referrer())
+        authenticated = authenticated_role(Session())
+        if role in (admin, guest, authenticated):
+            self.request.session.flash("You may not delete the {} role.".format(role.name), 'error')
+            return self.redirect(self.request.get_referrer(default=self.request.route_url('roles')))
 
 
 class RoleVersionView(VersionView):
