@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,21 +24,21 @@
 User Views
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 from sqlalchemy import orm
 
 from rattail.db import model
-from rattail.db.auth import guest_role, set_user_password
+from rattail.db.auth import guest_role, authenticated_role, set_user_password
 
 import formalchemy
 from formalchemy.fields import SelectFieldRenderer
 from webhelpers.html import HTML, tags
 
+from tailbone import forms
 from tailbone.db import Session
 from tailbone.views import MasterView
 from tailbone.views.continuum import VersionView, version_defaults
-from tailbone.forms import renderers
 
 
 def unique_username(value, field):
@@ -109,6 +109,7 @@ class RolesField(formalchemy.Field):
     def get_options(self):
         return Session.query(model.Role.name, model.Role.uuid)\
             .filter(model.Role.uuid != guest_role(Session()).uuid)\
+            .filter(model.Role.uuid != authenticated_role(Session()).uuid)\
             .order_by(model.Role.name)\
             .all()
 
@@ -141,6 +142,8 @@ class UsersView(MasterView):
         g.filters['active'].default_verb = 'is_true'
         g.filters['person'] = g.make_filter('person', model.Person.display_name, label="Person's Name",
                                             default_active=True, default_verb='contains')
+        g.filters['password'] = g.make_filter('password', model.User.password,
+                                              verbs=['is_null', 'is_not_null'])
 
         g.sorters['person'] = lambda q, d: q.order_by(getattr(model.Person.display_name, d)())
         g.default_sortkey = 'username'
@@ -154,11 +157,13 @@ class UsersView(MasterView):
             readonly=True)
 
     def configure_fieldset(self, fs):
-        fs.username.set(validate=unique_username)
+        fs.username.set(renderer=forms.renderers.StrippedTextFieldRenderer, validate=unique_username)
         fs.person.set(options=[])
-        fs.person.set(renderer=renderers.PersonFieldLinkRenderer)
+        fs.person.set(renderer=forms.renderers.PersonFieldLinkRenderer)
         fs.append(PasswordField('password', label="Set Password"))
+        fs.password.attrs(autocomplete='off')
         fs.append(formalchemy.Field('confirm_password', renderer=PasswordFieldRenderer))
+        fs.confirm_password.attrs(autocomplete='off')
         fs.append(RolesField('roles', renderer=RolesFieldRenderer(self.request)))
         fs.configure(
             include=[
@@ -170,6 +175,12 @@ class UsersView(MasterView):
                 fs.roles,
             ])
         if self.viewing:
+            permissions = self.request.registry.settings.get('tailbone_permissions', {})
+            renderer = forms.renderers.PermissionsFieldRenderer(permissions,
+                                                                include_guest=True,
+                                                                include_authenticated=True)
+            fs.append(formalchemy.Field('permissions', renderer=renderer))
+        if self.viewing or self.deleting:
             del fs.password
             del fs.confirm_password
 
